@@ -1,5 +1,5 @@
 /*
-** Copyright 2017-2019,2020 Thomas E. Dickey
+** Copyright 2017-2020,2021 Thomas E. Dickey
 ** Copyright 1997-2015,2017 Free Software Foundation, Inc.
 **
 ** This file is part of TACK.
@@ -19,7 +19,7 @@
 ** Boston, MA 02110-1301, USA
 */
 
-/* $Id: tack.h,v 1.80 2020/02/02 16:34:56 tom Exp $ */
+/* $Id: tack.h,v 1.89 2021/03/24 20:41:32 tom Exp $ */
 
 #ifndef NCURSES_TACK_H_incl
 #define NCURSES_TACK_H_incl 1
@@ -28,7 +28,7 @@
 
 #define MAJOR_VERSION 1
 #define MINOR_VERSION 9
-#define PATCH_VERSION 20200202
+#define PATCH_VERSION 20210324
 
 #ifdef HAVE_CONFIG_H
 #include <ncurses_cfg.h>
@@ -131,10 +131,10 @@
 extern void tack_edit_leaks(void);
 extern void tack_fun_leaks(void);
 #ifdef HAVE__NC_FREE_TINFO
-extern void _nc_free_tinfo(int) GCC_NORETURN;
+extern GCC_NORETURN void _nc_free_tinfo(int);
 #endif
 #ifndef ExitProgram
-extern void ExitProgram(int) GCC_NORETURN;
+extern GCC_NORETURN void ExitProgram(int);
 #endif
 #else
 #define ExitProgram(code) exit(code)
@@ -225,6 +225,9 @@ typedef enum {
 #define NAME_SIZE 32
 #define TEMP_SIZE 1024
 
+#define LOG_FILENAME "tack.log"
+#define DBG_FILENAME "debug.log"
+
 extern FILE *log_fp;
 extern FILE *debug_fp;
 extern int debug_level;
@@ -257,6 +260,7 @@ extern int raw_characters_sent;	/* Total output characters */
 
 /* definitions for pad.c */
 
+#define ENSURE_DELAY  if (!tt_delay_used) napms(10)
 #define EXIT_CONDITION (no_alarm_event && (tt_delay_used < tt_delay_max))
 #define SLOW_TERMINAL_EXIT if (!test_complete && !EXIT_CONDITION) { break; }
 #define CAP_NOT_FOUND if (auto_pad_mode) return
@@ -463,10 +467,12 @@ extern char *hex_expand_to(char *, int);
 extern char *print_expand(char *);
 extern int getchp(int);
 extern int getnext(int);
+extern int log_chr(FILE *, int, int);
 extern int tc_putp(const char *);
 extern int wait_here(void);
 extern void go_home(void);
 extern void home_down(void);
+extern void log_str(FILE *, const char *);
 extern void maybe_wait(int);
 extern void ptext(const char *);
 extern void ptextln(const char *);
